@@ -59,76 +59,28 @@ lazy_static! {
 fn initialize_types(pool: &DbPool) -> Result<()> {
     // BLOB_TYPE
     insert_entry(&pool.get()?, Entry::try_from(&*BLOB_TYPE_INVARIANT)?)?;
-    insert_entry(
-        &pool.get()?,
-        Entry {
-            entity: BLOB_TYPE_ADDR.clone(),
-            attribute: String::from(IS_OF_TYPE_ATTR),
-            value: EntryValue::Address(TYPE_ADDR.clone()),
-        },
-    )?;
-    insert_entry(
-        &pool.get()?,
-        Entry {
-            entity: BLOB_TYPE_ADDR.clone(),
-            attribute: String::from(TYPE_INSTANCED_ATTR),
-            value: EntryValue::Value(Value::from(FILE_TYPE)),
-        },
-    )?;
+    upend_insert_addr!(&pool.get()?, BLOB_TYPE_ADDR, IS_OF_TYPE_ATTR, TYPE_ADDR);
+    upend_insert_val!(&pool.get()?, BLOB_TYPE_ADDR, TYPE_INSTANCED_ATTR, FILE_TYPE);
+    upend_insert_val!(&pool.get()?, BLOB_TYPE_ADDR, TYPE_HAS_ATTR, FILE_MTIME_KEY);
+    upend_insert_val!(&pool.get()?, BLOB_TYPE_ADDR, TYPE_HAS_ATTR, FILE_SIZE_KEY);
+    upend_insert_val!(&pool.get()?, BLOB_TYPE_ADDR, TYPE_HAS_ATTR, FILE_MIME_KEY);
 
     // FILE_TYPE
     insert_entry(&pool.get()?, Entry::try_from(&*FILE_TYPE_INVARIANT)?)?;
-    insert_entry(
+    upend_insert_addr!(&pool.get()?, FILE_TYPE_ADDR, IS_OF_TYPE_ATTR, TYPE_ADDR);
+    upend_insert_val!(&pool.get()?, FILE_TYPE_ADDR, TYPE_ID_ATTR, FILENAME_KEY);
+    upend_insert_val!(
         &pool.get()?,
-        Entry {
-            entity: FILE_TYPE_ADDR.clone(),
-            attribute: String::from(IS_OF_TYPE_ATTR),
-            value: EntryValue::Address(TYPE_ADDR.clone()),
-        },
-    )?;
-    insert_entry(
-        &pool.get()?,
-        Entry {
-            entity: FILE_TYPE_ADDR.clone(),
-            attribute: String::from(TYPE_ID_ATTR),
-            value: EntryValue::Value(Value::from(FILENAME_KEY)),
-        },
-    )?;
-    insert_entry(
-        &pool.get()?,
-        Entry {
-            entity: FILE_TYPE_ADDR.clone(),
-            attribute: String::from(TYPE_REQUIRES_ATTR),
-            value: EntryValue::Value(Value::from(FILE_IDENTITY_KEY)),
-        },
-    )?;
-    insert_entry(
-        &pool.get()?,
-        Entry {
-            entity: FILE_TYPE_ADDR.clone(),
-            attribute: String::from(TYPE_HAS_ATTR),
-            value: EntryValue::Value(Value::from(FILE_MIME_KEY)),
-        },
-    )?;
+        FILE_TYPE_ADDR,
+        TYPE_REQUIRES_ATTR,
+        FILE_IDENTITY_KEY
+    );
+    upend_insert_val!(&pool.get()?, FILE_TYPE_ADDR, TYPE_HAS_ATTR, FILE_MIME_KEY);
 
     // DIR_TYPE
     insert_entry(&pool.get()?, Entry::try_from(&*DIR_TYPE_INVARIANT)?)?;
-    insert_entry(
-        &pool.get()?,
-        Entry {
-            entity: DIR_TYPE_ADDR.clone(),
-            attribute: String::from(IS_OF_TYPE_ATTR),
-            value: EntryValue::Address(TYPE_ADDR.clone()),
-        },
-    )?;
-    insert_entry(
-        &pool.get()?,
-        Entry {
-            entity: DIR_TYPE_ADDR.clone(),
-            attribute: String::from(TYPE_ID_ATTR),
-            value: EntryValue::Value(Value::from(DIR_KEY)),
-        },
-    )?;
+    upend_insert_addr!(&pool.get()?, DIR_TYPE_ADDR, IS_OF_TYPE_ATTR, TYPE_ADDR);
+    upend_insert_val!(&pool.get()?, DIR_TYPE_ADDR, TYPE_ID_ATTR, DIR_KEY);
 
     Ok(())
 }
